@@ -128,10 +128,13 @@ def test_DocumentNTF():
 	form = 'CRFB'
 	ntf = synthesizeNTF(order, osr, 2, Hinf, f0)
 	a, g, b, c = realizeNTF(ntf, form)
-	b = np.hstack(( # Use a single feed-in for the input
-	               np.atleast_2d(b[0, 0]),
-	               np.zeros((1, max(b.shape)-1))
+	b = np.concatenate(( # Use a single feed-in for the input
+	               np.atleast_1d(b[0]),
+	               np.zeros((max(b.shape) - 1))
 	              ))
 	ABCD = stuffABCD(a, g, b, c, form)
 	DocumentNTF(ABCD, osr, f0)
 	assert True # we check that DocumentNTF plots with no errors.
+	ntf = synthesizeNTF(order, osr, 2, Hinf, f0=.333)
+	DocumentNTF(ntf, osr, f0=.333)
+	assert True # we check that DocumentNTF plots with no errors.
