@@ -4,7 +4,7 @@
 # Copyright 2013 Giuseppe Venturini
 # This file is part of python-deltasigma.
 #
-# python-deltasigma is a 1:1 Python replacement of Richard Schreier's 
+# python-deltasigma is a 1:1 Python replacement of Richard Schreier's
 # MATLAB delta sigma toolbox (aka "delsigma"), upon which it is heavily based.
 # The delta sigma toolbox is (c) 2009, Richard Schreier.
 #
@@ -49,6 +49,8 @@ at the following ipython notebooks:
    notebook port of the interactive ``dsdemo1.m``.
 -  `dsdemo2 <http://nbviewer.ipython.org/gist/ggventurini/8044644>`__,
    notebook port of the interactive ``dsdemo2.m``.
+-  `dsdemo3 <http://nbviewer.ipython.org/gist/ggventurini/10016971>`__,
+   notebook port of the interactive ``dsdemo3.m``.
 -  `dsdemo4 <http://nbviewer.ipython.org/gist/ggventurini/8255785/dsdemo4.ipynb>`__,
    notebook port of ``dsdemo4.m``. `Audio
    file <https://gist.github.com/ggventurini/8255785/raw/8fb7d94236b917e6d557fb538d3f35a3144c038c/sax.wav.b64>`__.
@@ -67,7 +69,7 @@ list.
 
 |Build Status| |Coverage Status|
 
-For more detailed information about the development status take a look at 
+For more detailed information about the development status take a look at
 `files.csv <https://github.com/ggventurini/python-deltasigma/blob/master/files.csv>`__.
 
 The further functionality is expected to be ported according to `the
@@ -139,7 +141,7 @@ Index (PYPI) <http://pypi.python.org>`__, running::
 The above command will also attempt to compile and install the dependencies -
 for this to work you should already have the required libraries in place.
 
-Otherwise, you can head over to `the Github repository 
+Otherwise, you can head over to `the Github repository
 <http://github.com/ggventurini/python-deltasigma>`__ and download the code
 from there.
 
@@ -246,10 +248,10 @@ License, copyright, rationale and credits
 Why this project was born
 ~~~~~~~~~~~~~~~~~~~~~~~~~
 
-I like challenges, Delta Sigma modulation and I don't have the money for
+I like challenges, delta-sigma modulation and I don't have the money for
 my own MATLAB license.
 
-With this Python package you can simulate Delta Sigma modulators for
+With this Python package you can simulate delta-sigma modulators for
 free, on any PC.
 
 I hope you find it useful.
@@ -285,9 +287,9 @@ MATLAB is a registered trademark of The MathWorks, Inc.
 Credits
 ~~~~~~~
 
-The ``python-deltasigma`` package was written by 
+The ``python-deltasigma`` package was written by
 `Giuseppe Venturini <https://github.com/ggventurini>`__, as a derivative work
-of Richard Schreier's MATLAB Delta Sigma toolbox. It contains code from 
+of Richard Schreier's MATLAB Delta Sigma toolbox. It contains code from
 ``pydsm``, also based on the same MATLAB toolbox and written by Sergio
 Callegari.
 
@@ -305,29 +307,31 @@ upon which the following documentation is very heavily based.
 Modulator model
 ~~~~~~~~~~~~~~~
 
-A delta-sigma modulator with a single quantizer is assumed to consist of 
+A delta-sigma modulator with a single quantizer is assumed to consist of
 quantizer connected to a loop filter as shown in the diagram below.
 
 .. image:: ../doc/_static/modulator_model.png
     :align: center
     :alt: Modulator model
 
+.. _loop-filter-label:
+
 The loop filter
 :::::::::::::::
 
-The loop filter is described by an :math:`ABCD` matrix. For single-quantizer 
-systems, the loop filter is a two-input, one-output linear system and 
+The loop filter is described by an :math:`ABCD` matrix. For single-quantizer
+systems, the loop filter is a two-input, one-output linear system and
 :math:`ABCD` is an :math:`(n+1, n+2)` matrix, partitioned into
 :math:`A` :math:`(n, n)`, :math:`B` :math:`(n, 2)`, :math:`C` :math:`(1, n)`
 and :math:`D` :math:`(1, 2)` sub-matrices as shown below:
 
 .. math::
 
-    ABCD = 
+    ABCD =
         \\left[
         \\begin{array}{c|c}
           A & B \\\\ \\hline
-          C & D 
+          C & D
         \\end{array}
         \\right].
 
@@ -345,7 +349,7 @@ The equations for updating the state and computing the output of the loop filter
 
 .. math::
 
-    y(n + 1) = Cx(n) + D
+    y(n) = Cx(n) + D
         \\left[
         \\begin{array}{c}
           u(n) \\\\
@@ -353,7 +357,7 @@ The equations for updating the state and computing the output of the loop filter
         \\end{array}
         \\right].
 
-Where :math:`u(n)` is the input sequence and :math:`v(n)` is the modulator output sequence. 
+Where :math:`u(n)` is the input sequence and :math:`v(n)` is the modulator output sequence.
 
 This formulation is sufficiently general to encompass all single-quantizer modulators which
 employ linear loop filters. The toolbox currently supports translation to/from an ABCD descrip-
@@ -375,7 +379,7 @@ See :ref:`topologies-diagrams` for a block-level view of the different modulator
 Multi-input and multi-quantizer systems can also be described with an
 ABCD matrix and the previous equation
 will still apply. For an :math:`n_i`-input, :math:`n_o`-output modulator,
-the dimensions of the sub-matrices are 
+the dimensions of the sub-matrices are
 :math:`A`: :math:`(n, n)`, :math:`B`: :math:`(n, n_i + n_o)`,
 :math:`C`: :math:`(n_o, n)` and :math:`D`: :math:`(n_o, n_i+n_o)`.
 
@@ -498,67 +502,10 @@ The following are auxiliary functions that complement the key functions above.
     pulse
     rmsGain
 
-General utilities for data processing
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+Utility functions for simulation of delta-sigma modulators
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-The following are generic functions useful for manipulating data,
-conversions, padding and provide speciality functions which are
-not otherwise available in the usual scientific Python stack.
-
-.. autosummary::
-    :nosignatures:
-
-    db
-    dbm
-    dbp
-    dbv
-    undbm
-    undbp
-    undbv
-    rms
-    padb
-    padl
-    padr
-    padt
-    cplxpair
-    mfloor
-    rat
-    gcd
-    lcm
-
-Plotting and data display utilitites
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
-Graphic functions:
-
-.. autosummary::
-    :nosignatures:
-
-    plotPZ
-    plotSpectrum
-    figureMagic
-    DocumentNTF
-    PlotExampleSpectrum
-    axisLabels
-    bilogplot
-    bplogsmooth
-    lollipop
-    changeFig
-
-Textual and non-graphic functions
-
-.. autosummary::
-    :nosignatures:
-
-    circ_smooth
-    logsmooth
-    pretty_lti
-    SIunits
-
-Utility functions for Delta Sigma simulation
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
-Functions for low-level handling of Delta Sigma modulator representations,
+Functions for low-level handling of delta-sigma modulator representations,
 their evaluation and filtering.
 
 .. autosummary::
@@ -584,6 +531,65 @@ their evaluation and filtering.
     sinc_decimate
     zinc
 
+General utilities for data processing
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+The following are generic functions, useful for misc. tasks, like
+manipulating data, conversions or padding, for example.
+They provide speciality functions which are not otherwise available
+in the usual scientific Python stack.
+
+.. autosummary::
+    :nosignatures:
+
+    db
+    dbm
+    dbp
+    dbv
+    undbm
+    undbp
+    undbv
+    rms
+    padb
+    padl
+    padr
+    padt
+    cplxpair
+    mfloor
+    mround
+    rat
+    gcd
+    lcm
+
+Plotting and data display utilitites
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+Graphic functions:
+
+.. autosummary::
+    :nosignatures:
+
+    plotPZ
+    plotSpectrum
+    figureMagic
+    DocumentNTF
+    PlotExampleSpectrum
+    axisLabels
+    bilogplot
+    lollipop
+    changeFig
+
+Textual and non-graphic display-related functions
+
+.. autosummary::
+    :nosignatures:
+
+    circ_smooth
+    bplogsmooth
+    logsmooth
+    pretty_lti
+    SIunits
+
 All functions in alphabetical order
 -----------------------------------
 
@@ -592,21 +598,22 @@ All functions in alphabetical order
 __author__ = "Giuseppe Venturini and the python-deltasigma contributors"
 __copyright__ = "Copyright 2013, Giuseppe Venturini"
 __credits__ = ["Giuseppe Venturini"]
-__license__ = "BSD 3-Clause License"
-__version__ = '0.1-1'
+__license__ = "BSD 2-Clause License"
+__version__ = '0.1-2'
 __maintainer__ = "Giuseppe Venturini"
 __email__ = "ggventurini+github@gmail.com"
 __status__ = "Stable"
 
 # Package testing can be done remotely, without display. This would make
 # matplotlib fail (and consequently, the test itself).
-# We check for $DISPLAY, but this makes us probably lose in portability, 
+# We check for $DISPLAY, but this makes us probably lose in portability,
 # does Windows have this environment variable defined?
 # Then again, who runs the test suit on a head-less windows machine...
 # ... for the time being the following should be OK. If in the future that
 # feature is needed by somebody, we can switch to
 # if not os.system('python -c "import matplotlib.pyplot as plt;plt.figure()"')
-import matplotlib, os
+import matplotlib
+import os
 if not ('DISPLAY' in os.environ or os.environ.get('READTHEDOCS', None)):
     matplotlib.use('Agg')
 
@@ -682,5 +689,5 @@ from ._thermometer import thermometer
 from ._undbm import undbm
 from ._undbp import undbp
 from ._undbv import undbv
-from ._utils import circshift, cplxpair, mfloor, pretty_lti, rat, gcd, lcm
+from ._utils import circshift, cplxpair, mfloor, mround, pretty_lti, rat, gcd, lcm
 from ._zinc import zinc
